
From: Rajesh Shah <rajesh.shah@intel.com>

This patch reads and stores host bridge resources reported by ACPI BIOS for
x86_64 systems.  This is needed since ACPI hotplug code now uses the PCI
core for resource management.  This patch simply adds the boot parameter
(acpi=root_resources) to enable the functionality that is implemented in
arch/i386.

Signed-off-by: Rajesh Shah <rajesh.shah@intel.com>

(akpm: Andi hates the boot option)
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 arch/x86_64/kernel/setup.c |    3 +++
 include/asm-x86_64/acpi.h  |    6 ++++++
 2 files changed, 9 insertions(+)

diff -puN arch/x86_64/kernel/setup.c~x86_64-collect-host-bridge-resources arch/x86_64/kernel/setup.c
--- 25/arch/x86_64/kernel/setup.c~x86_64-collect-host-bridge-resources	Mon May 23 16:13:28 2005
+++ 25-akpm/arch/x86_64/kernel/setup.c	Mon May 23 16:13:28 2005
@@ -315,6 +315,9 @@ static __init void parse_cmdline_early (
 			acpi_disable_pci();
 		else if (!memcmp(from, "acpi=noirq", 10))
 			acpi_noirq_set();
+		/* Use ACPI to read host bridge resources */
+		else if (!memcmp(from, "acpi=root_resources", 19))
+			acpi_set_read_root_resources();
 
 		else if (!memcmp(from, "acpi_sci=edge", 13))
 			acpi_sci_flags.trigger =  1;
diff -puN include/asm-x86_64/acpi.h~x86_64-collect-host-bridge-resources include/asm-x86_64/acpi.h
--- 25/include/asm-x86_64/acpi.h~x86_64-collect-host-bridge-resources	Mon May 23 16:13:28 2005
+++ 25-akpm/include/asm-x86_64/acpi.h	Mon May 23 16:13:28 2005
@@ -139,10 +139,16 @@ static inline void acpi_disable_pci(void
 	acpi_noirq_set();
 }
 extern int acpi_irq_balance_set(char *str);
+extern int acpi_read_root_resources;
+static inline void acpi_set_read_root_resources(void)
+{
+	acpi_read_root_resources = 1;
+}
 #else
 static inline void acpi_noirq_set(void) { }
 static inline void acpi_disable_pci(void) { }
 static inline int acpi_irq_balance_set(char *str) { return 0; }
+static inline void acpi_set_read_root_resources(void) { }
 #endif
 
 #ifdef CONFIG_ACPI_SLEEP
_
